@@ -7,9 +7,21 @@ import six
 from ._api import get_server_api_connection
 from .utils import create_entity_id, convert_entity_id, slugify_string
 
-UNKNOWN_VALUE = object()
-PROJECT_PARENT_ID = object()
-_NOT_SET = object()
+
+class _CustomNone(object):
+    def __init__(self, name=None):
+        self._name = name or "CustomNone"
+
+    def __repr__(self):
+        return "<{}>".format(self._name)
+
+    def __bool__(self):
+        return False
+
+
+UNKNOWN_VALUE = _CustomNone("UNKNOWN_VALUE")
+PROJECT_PARENT_ID = _CustomNone("PROJECT_PARENT_ID")
+_NOT_SET = _CustomNone("_NOT_SET")
 
 
 class EntityHub(object):
@@ -219,7 +231,10 @@ class EntityHub(object):
             return None
 
         if entity_type == "folder":
-            return self.add_folder(entity_data)
+            folder_entity = self.add_folder(entity_data)
+            folder_entity.has_published_content = entity_data["hasProducts"]
+            return folder_entity
+
         elif entity_type == "task":
             return self.add_task(entity_data)
 
@@ -471,13 +486,14 @@ class EntityHub(object):
         }
         for folder in folders:
             folder_entity = self._entities_by_id.get(folder["id"])
-            if folder_entity is not None:
-                if folder_entity.parent_id == entity.id:
-                    children_ids.add(folder_entity.id)
-                continue
+            if folder_entity is None:
+                folder_entity = self.add_folder(folder)
+                children_ids.add(folder_entity.id)
 
-            folder_entity = self.add_folder(folder)
-            children_ids.add(folder_entity.id)
+            elif folder_entity.parent_id == entity.id:
+                children_ids.add(folder_entity.id)
+
+            folder_entity.has_published_content = folder["hasProducts"]
 
         for task in tasks:
             task_entity = self._entities_by_id.get(task["id"])
@@ -1284,7 +1300,10 @@ class BaseEntity(object):
             changes["name"] = self._name
 
         if self._entity_hub.allow_data_changes:
-            if self._orig_data != self._data:
+            if (
+                self._data is not UNKNOWN_VALUE
+                and self._orig_data != self._data
+            ):
                 changes["data"] = self._data
 
         if self._orig_thumbnail_id != self._thumbnail_id:
@@ -2549,7 +2568,10 @@ class FolderEntity(BaseEntity):
         if self.thumbnail_id is not UNKNOWN_VALUE:
             output["thumbnailId"] = self.thumbnail_id
 
-        if self._entity_hub.allow_data_changes:
+        if (
+            self._entity_hub.allow_data_changes
+            and self._data is not UNKNOWN_VALUE
+        ):
             output["data"] = self._data
         return output
 
